dhcpkit.ipv6.server.extension_registry module
=============================================

.. automodule:: dhcpkit.ipv6.server.extension_registry
    :members:
    :undoc-members:
    :show-inheritance:
